@@ -1,6 +1,8 @@
-import os,subprocess,platform,time,threading
+import platform,time,threading
 if platform.system()=='Windows':
     import wmi
+else:
+    import subprocess,os
     
 def set_brightness(brightness_level,force=False,raw_value=False):
     '''
@@ -8,7 +10,6 @@ def set_brightness(brightness_level,force=False,raw_value=False):
     force (linux only) - if you set the brightness to 0 on linux it will actually apply that value (which turns the screen off)
     raw_value (linux only) - means you have not supplied a percentage but an actual brightness value
     '''
-
     if type(brightness_level)==str and any(n in brightness_level for n in ('+','-')):
         current_brightness=get_brightness(raw_value=raw_value)
         if current_brightness==False:
@@ -36,6 +37,8 @@ def set_brightness(brightness_level,force=False,raw_value=False):
         #if the function has not already returned it means we could not adjust the backlight using those tools
         backlight_dir='/sys/class/backlight/'
         if os.path.isdir(backlight_dir) and os.listdir(backlight_dir)!=[]:
+            #make absolutely sure this var is the correct type
+            brightness_level=int(float(str(brightness_level)))
             #if the backlight dir exists and is not empty
             folders=[folder for folder in os.listdir(backlight_dir) if os.path.isdir(os.path.join(backlight_dir,folder))]
             for folder in folders:
@@ -69,8 +72,8 @@ def fade_brightness(finish, start=None, interval=0.01, increment=1, blocking=Tru
     finish - the brighness level we end on
     start - where the brightness should fade from
     interval - the time delay between each step in brightness
-    blocking - whether this should occur in the main thread (True) or a new daemonic thread (False)
     increment - the amount to change the brightness by per loop
+    blocking - whether this should occur in the main thread (True) or a new daemonic thread (False)
     '''
     def fade():
         for i in range(min(start,finish),max(start,finish),increment):
@@ -110,11 +113,14 @@ def fade_brightness(finish, start=None, interval=0.01, increment=1, blocking=Tru
          try:return fade()
          except:return False
          
-def get_brightness(raw_value=False):
+def get_brightness(max_value=False,raw_value=False):
     '''
+    max_value - returns the maximum brightness the monitor can be set to. Always returns 100 on Windows but on linux it returns the value stored in /sys/class/backlight/*/max_brightness if used with raw_value
     raw_value (linux only) - means the brightness will not be returned as a percentage but directly as it is in /sys/class/backlight/*/brightness
     '''
     if platform.system()=='Windows':
+        if max_value:
+            return 100
         return wmi.WMI(namespace='wmi').WmiMonitorBrightness()[0].CurrentBrightness
     elif platform.system()=='Linux':
         if not raw_value:
@@ -122,6 +128,8 @@ def get_brightness(raw_value=False):
             for command in possible_commands:
                 try:
                     res=subprocess.run(command.split(' '),stdout=subprocess.PIPE).stdout.decode()
+                    if max_value:
+                        return 100
                     return int(float(str(res)))
                 except:
                     pass
@@ -145,6 +153,8 @@ def get_brightness(raw_value=False):
                             #if the file does not exist use 100
                             max_brightness=100
                             brightness_value=(int(brightness_value/max_brightness)*100)
+                    if max_value:
+                        return max_brightness
                     return brightness_value
 
                 except:
@@ -153,5 +163,5 @@ def get_brightness(raw_value=False):
     elif platform.system()=='Darwin':
         return False
     
-__version__='0.1.6'
+__version__='0.1.7'
 __author__='Crozzers'
